@@ -1,3 +1,11 @@
+"""
+sentry.client.handlers
+~~~~~~~~~~~~~~~~~~~~~~
+
+:copyright: (c) 2010 by the Sentry Team, see AUTHORS for more details.
+:license: BSD, see LICENSE for more details.
+"""
+
 import logging
 import sys
 import traceback
