@@ -1,3 +1,11 @@
+"""
+sentry.client.models
+~~~~~~~~~~~~~~~~~~~~
+
+:copyright: (c) 2010 by the Sentry Team, see AUTHORS for more details.
+:license: BSD, see LICENSE for more details.
+"""
+
 from __future__ import absolute_import
 
 import sys
