@@ -1,5 +1,11 @@
 """
+sentry.conf.defaults
+~~~~~~~~~~~~~~~~~~~~
+
 Represents the default values for all Sentry settings.
+
+:copyright: (c) 2010 by the Sentry Team, see AUTHORS for more details.
+:license: BSD, see LICENSE for more details.
 """
 
 import logging
