@@ -1,5 +1,11 @@
 """
+sentry.conf.server
+~~~~~~~~~~~~~~~~~~
+
 These settings act as the default (base) settings for the Sentry-provided web-server
+
+:copyright: (c) 2010 by the Sentry Team, see AUTHORS for more details.
+:license: BSD, see LICENSE for more details.
 """
 
 from django.conf.global_settings import *
