@@ -16,6 +16,11 @@ import datetime
 
 register = template.Library()
 
+# seriously Django?
+@register.filter
+def plus(value, amount):
+    return int(value) + int(amount)
+
 @register.filter
 def has_charts(group):
     from sentry.utils.charts import has_charts
@@ -36,7 +41,7 @@ def is_dict(value):
 @register.filter
 def with_priority(result_list, key='score'):
     if result_list:
-        if isinstance(result_list[0], dict):
+        if isinstance(result_list[0], (dict, list, tuple)):
             _get = lambda x, k: x[k]
         else:
             _get = lambda x, k: getattr(x, k)
